..
      Copyright European Organization for Nuclear Research (CERN)

      Licensed under the Apache License, Version 2.0 (the "License");
      You may not use this file except in compliance with the License.
      You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0

------------------------------------------------------------
Detect that a site has reached the space occupancy watermark
------------------------------------------------------------

Periodically update the space occupancy for each external storage system.

.. sequence-diagram::

     Daemon::
     DB::
     Storage::{locationName}

     [c:loop]
     Daemon:occupancy=Storage.getSpaceOccupancy()
     Daemon:DB.store(locationName, occupancy)
     Daemon:Daemon.compareAndNotify()
     [/c]
